********
Routines
********

In this chapter routine docstrings are presented, grouped by functionality.
Many docstrings contain example code, which demonstrates basic usage
of the routine. The examples assume that NumPy is imported with::

  >>> import numpy as np

A convenient way to execute examples is the ``%doctest_mode`` mode of
IPython, which allows for pasting of multi-line examples and preserves
indentation.

.. toctree::
   :maxdepth: 2

   routines.array-creation
   routines.array-manipulation
   routines.bitwise
   routines.char
   routines.ctypeslib
   routines.datetime
   routines.dtype
   routines.dual
   routines.emath
   routines.err
   routines.fft
   routines.financial
   routines.functional
   routines.help
   routines.indexing
   routines.io
   routines.linalg
   routines.logic
   routines.ma
   routines.math
   routines.matlib
   routines.other
   routines.padding
   routines.polynomials
   routines.random
   routines.set
   routines.sort
   routines.statistics
   routines.testing
   routines.window
